@@ -6,6 +6,7 @@ use gtk::prelude::*;
 use windows_sys::Win32::Foundation::PSTR;
 #[cfg(windows)]
 use windows_sys::Win32::UI::WindowsAndMessaging::*;
+use crate::windowclass::WindowClass;
 
 // Default
 
@@ -29,12 +30,6 @@ pub const DEFAULT_WINDOW_Y: i32 = 500;
 #[cfg(linux)]
 pub const DEFAULT_WINDOW_Y: i32 = 1280;
 
-#[cfg(windows)]
-pub const DEFAULT_WINDOW_CLASS: PSTR = b"window\0".as_ptr() as _;
-
-#[cfg(linux)]
-pub const DEFAULT_WINDOW_CLASS: String = "window".parse().unwrap();
-
 // Button Styles
 
 #[cfg(windows)]
