@@ -2,16 +2,12 @@ use nxui::NativesAndMessaging::*;
 use nxui::{messagebox, window, windowclass};
 
 fn main() {
-    let class = windowclass::WindowClass::new("window".to_string(), "io.github.lattesyobon.space".to_string());
-    let window = window::Window::new(
-        class,
-        "Hello World".to_string(),
-        1280,
-        750,
-        500,
-        500,
+    let class = windowclass::WindowClass::new(
+        "window".to_string(),
+        "io.github.lattesyobon.space".to_string(),
     );
-    window.show(WINDOWSTYLE_SYSMENU);
+    let window = window::Window::new(class, "Hello World".to_string(), 1280, 750, 500, 500);
+    window.show(WINDOWSTYLE_OVERLAPPED);
     let msg_box = messagebox::MessageBox::new("Hello!".parse().unwrap(), "world".parse().unwrap());
     // Normal Dialog
     msg_box.show(BUTTONSTYLE_NONE, DIALOGSTYLE_NONE, DIALOGHINT_MODAL);
